@@ -79,12 +79,12 @@ public:
     virtual QWidget *widget() = 0;
 
     bool testGL();
-    virtual bool setVSync(bool enable) = 0;
+    virtual void setVSync(bool enable) = 0;
     virtual void updateGL(bool requestDelayed) = 0;
 
     void setX11BypassCompositor(bool bypassCompositor);
 #ifdef Q_OS_WIN
-    void setWindowsBypassCompositor(Qt::CheckState bypassCompositor);
+    void setWindowsBypassCompositor(bool bypassCompositor);
 #endif
 
     void newSize(const QSize &size = QSize());
@@ -169,8 +169,6 @@ public:
     int subsX, subsY, W, H, subsW, subsH, outW, outH, verticesIdx;
     int glVer;
 
-    QString m_glVendor;
-
     double aspectRatio, zoom;
 
     bool moveVideo = false, moveOSD = false;
