@@ -58,9 +58,9 @@ private:
     OpenGL2Common *drawable;
     bool allowPBO;
     bool m_hqScaling = false;
-    bool forceRtt, useRtt;
+    bool useRtt = false;
     bool vSync;
-    Qt::CheckState m_bypassCompositor = Qt::PartiallyChecked;
+    bool m_bypassCompositor = false;
 };
 
 #define OpenGL2WriterName "OpenGL 2"
